@@ -1,7 +1,7 @@
 import abc
 from typing import *
 
-from .base import *
+from base import *
 
 __all__ = ('SupervisedLearnerPrimitiveBase',)
 
